@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Manipulate the position of notes in a scale
 
-our $VERSION = '0.0301';
+our $VERSION = '0.0302';
 
 use Carp;
 use Moo;
@@ -27,6 +27,17 @@ has scale_name => (
 );
 
 
+has note_format => (
+    is => 'ro',
+);
+
+
+has offset => (
+    is  => 'ro',
+    isa => sub { die 'Not an integer' unless $_[0] =~ /^\d+$/ },
+);
+
+
 has verbose => (
     is      => 'ro',
     default => sub { 0 },
@@ -36,6 +47,9 @@ has verbose => (
 sub get_offset {
     my ( $self, %args ) = @_;
 
+    $args{note_format} ||= $self->note_format;
+    $args{offset}      ||= $self->offset;
+
     croak 'note_name, note_format or offset not provided'
         unless $args{note_name} || $args{note_format} || $args{offset};
 
@@ -110,7 +124,7 @@ Music::ScaleNote - Manipulate the position of notes in a scale
 
 =head1 VERSION
 
-version 0.0301
+version 0.0302
 
 =head1 SYNOPSIS
 
@@ -155,6 +169,16 @@ Please see L<Music::Scales/SCALES> for the possible names.
 
 Default: major
 
+=head2 note_format
+
+The format as given by L<Music::Note/STYLES>.  If given in the constructor, this
+is used as the default in the B<get_offset> method.
+
+=head2 offset
+
+The integer offset of a new scale position.  If given in the constructor, this
+is used as the default in the B<get_offset> method.
+
 =head2 verbose
 
 Show the progress of the B<get_offset> method.
